import pytest

from huawei_solar.exceptions import PeakPeriodsValidationError
import huawei_solar.register_names as rn
from huawei_solar.registers import REGISTERS, PeakSettingPeriod

ppr = REGISTERS[rn.STORAGE_CAPACITY_CONTROL_PERIODS]


def test_simple():

    pp_valid = [
        PeakSettingPeriod(
            start_time=0, end_time=1440, power=2.5, days_effective=[True, True, True, True, True, True, True]
        )
    ]

    assert ppr._validate(pp_valid) is None


def test_invalid_start_time():
    pp = [
        PeakSettingPeriod(
            start_time=60 * 24 + 1, end_time=15, power=2.5, days_effective=[True, True, True, True, True, True, True]
        )
    ]

    with pytest.raises(expected_exception=PeakPeriodsValidationError, match="Every day must be covered from 00:00"):
        ppr._validate(pp)


def test_invalid_end_time():
    pp = [
        PeakSettingPeriod(
            start_time=0, end_time=15, power=2.5, days_effective=[True, True, True, True, True, True, True]
        )
    ]

    with pytest.raises(expected_exception=PeakPeriodsValidationError, match="Every day must be covered until 23:59"):
        ppr._validate(pp)

    pp2 = [
        PeakSettingPeriod(
            start_time=0, end_time=1441, power=2.5, days_effective=[True, True, True, True, True, True, True]
        )
    ]

    with pytest.raises(expected_exception=PeakPeriodsValidationError, match="Every day must be covered until 23:59"):
        ppr._validate(pp2)


def test_all_days_of_week_covered():
    pp = [
        PeakSettingPeriod(
            start_time=0, end_time=15, power=2.5, days_effective=[False, True, True, True, True, True, True]
        )
    ]

    with pytest.raises(expected_exception=PeakPeriodsValidationError, match="All days of the week need to be covered"):
        ppr._validate(pp)


def test_multiple_periods_on_a_day():
    pp = [
        PeakSettingPeriod(
            start_time=0, end_time=1439, power=2.5, days_effective=[False, True, True, True, True, True, True]
        ),
        PeakSettingPeriod(
            start_time=0, end_time=600, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
        PeakSettingPeriod(
            start_time=600, end_time=1439, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
    ]

    assert ppr._validate(pp) is None

    pp2 = [
        PeakSettingPeriod(
            start_time=0, end_time=1439, power=2.5, days_effective=[False, True, True, True, True, True, True]
        ),
        PeakSettingPeriod(
            start_time=0, end_time=600, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
        PeakSettingPeriod(
            start_time=601, end_time=1439, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
    ]

    assert ppr._validate(pp2) is None

    pp3 = [
        PeakSettingPeriod(
            start_time=0, end_time=1439, power=2.5, days_effective=[False, True, True, True, True, True, True]
        ),
        PeakSettingPeriod(
            start_time=0, end_time=600, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
        PeakSettingPeriod(
            start_time=602, end_time=1439, power=2.5, days_effective=[True, False, False, False, False, False, False]
        ),
    ]

    with pytest.raises(
        expected_exception=PeakPeriodsValidationError, match="All moments of each day need to be covered"
    ):
        ppr._validate(pp3)



"""Register names from the Huawei inverter"""

MODEL_NAME = "model_name"
SERIAL_NUMBER = "serial_number"
PN = "pn"
MODEL_ID = "model_id"
NB_PV_STRINGS = "nb_pv_strings"
NB_MPP_TRACKS = "nb_mpp_tracks"
RATED_POWER = "rated_power"
P_MAX = "P_max"
S_MAX = "S_max"
Q_MAX_OUT = "Q_max_out"
Q_MAX_IN = "Q_max_in"
STATE_1 = "state_1"
STATE_2 = "state_2"
STATE_3 = "state_3"
ALARM_1 = "alarm_1"
ALARM_2 = "alarm_2"
ALARM_3 = "alarm_3"
PV_01_VOLTAGE = "pv_01_voltage"
PV_01_CURRENT = "pv_01_current"
PV_02_VOLTAGE = "pv_02_voltage"
PV_02_CURRENT = "pv_02_current"
PV_03_VOLTAGE = "pv_03_voltage"
PV_03_CURRENT = "pv_03_current"
PV_04_VOLTAGE = "pv_04_voltage"
PV_04_CURRENT = "pv_04_current"
PV_05_VOLTAGE = "pv_05_voltage"
PV_05_CURRENT = "pv_05_current"
PV_06_VOLTAGE = "pv_06_voltage"
PV_06_CURRENT = "pv_06_current"
PV_07_VOLTAGE = "pv_07_voltage"
PV_07_CURRENT = "pv_07_current"
PV_08_VOLTAGE = "pv_08_voltage"
PV_08_CURRENT = "pv_08_current"
PV_09_VOLTAGE = "pv_09_voltage"
PV_09_CURRENT = "pv_09_current"
PV_10_VOLTAGE = "pv_10_voltage"
PV_10_CURRENT = "pv_10_current"
PV_11_VOLTAGE = "pv_11_voltage"
PV_11_CURRENT = "pv_11_current"
PV_12_VOLTAGE = "pv_12_voltage"
PV_12_CURRENT = "pv_12_current"
PV_13_VOLTAGE = "pv_13_voltage"
PV_13_CURRENT = "pv_13_current"
PV_14_VOLTAGE = "pv_14_voltage"
PV_14_CURRENT = "pv_14_current"
PV_15_VOLTAGE = "pv_15_voltage"
PV_15_CURRENT = "pv_15_current"
PV_16_VOLTAGE = "pv_16_voltage"
PV_16_CURRENT = "pv_16_current"
PV_17_VOLTAGE = "pv_17_voltage"
PV_17_CURRENT = "pv_17_current"
PV_18_VOLTAGE = "pv_18_voltage"
PV_18_CURRENT = "pv_18_current"
PV_19_VOLTAGE = "pv_19_voltage"
PV_19_CURRENT = "pv_19_current"
PV_20_VOLTAGE = "pv_20_voltage"
PV_20_CURRENT = "pv_20_current"
PV_21_VOLTAGE = "pv_21_voltage"
PV_21_CURRENT = "pv_21_current"
PV_22_VOLTAGE = "pv_22_voltage"
PV_22_CURRENT = "pv_22_current"
PV_23_VOLTAGE = "pv_23_voltage"
PV_23_CURRENT = "pv_23_current"
PV_24_VOLTAGE = "pv_24_voltage"
PV_24_CURRENT = "pv_24_current"
INPUT_POWER = "input_power"
GRID_VOLTAGE = "grid_voltage"
LINE_VOLTAGE_A_B = "line_voltage_A_B"
LINE_VOLTAGE_B_C = "line_voltage_B_C"
LINE_VOLTAGE_C_A = "line_voltage_C_A"
PHASE_A_VOLTAGE = "phase_A_voltage"
PHASE_B_VOLTAGE = "phase_B_voltage"
PHASE_C_VOLTAGE = "phase_C_voltage"
GRID_CURRENT = "grid_current"
PHASE_A_CURRENT = "phase_A_current"
PHASE_B_CURRENT = "phase_B_current"
PHASE_C_CURRENT = "phase_C_current"
DAY_ACTIVE_POWER_PEAK = "day_active_power_peak"
ACTIVE_POWER = "active_power"
REACTIVE_POWER = "reactive_power"
POWER_FACTOR = "power_factor"
GRID_FREQUENCY = "grid_frequency"
EFFICIENCY = "efficiency"
INTERNAL_TEMPERATURE = "internal_temperature"
INSULATION_RESISTANCE = "insulation_resistance"
DEVICE_STATUS = "device_status"
FAULT_CODE = "fault_code"
STARTUP_TIME = "startup_time"
SHUTDOWN_TIME = "shutdown_time"
ACCUMULATED_YIELD_ENERGY = "accumulated_yield_energy"
UNKNOWN_TIME_1 = "unknown_time_1"
DAILY_YIELD_ENERGY = "daily_yield_energy"
UNKNOWN_TIME_2 = "unknown_time_2"
UNKNOWN_TIME_3 = "unknown_time_3"
UNKNOWN_TIME_4 = "unknown_time_4"
STORAGE_UNIT_1_RUNNING_STATUS = "storage_unit_1_running_status"
STORAGE_UNIT_1_CHARGE_DISCHARGE_POWER = "storage_unit_1_charge_discharge_power"
STORAGE_UNIT_1_BUS_VOLTAGE = "storage_unit_1_bus_voltage"
STORAGE_UNIT_1_STATE_OF_CAPACITY = "storage_unit_1_state_of_capacity"
STORAGE_UNIT_1_WORKING_MODE_B = "storage_unit_1_working_mode_b"
STORAGE_UNIT_1_RATED_CHARGE_POWER = "storage_unit_1_rated_charge_power"
STORAGE_UNIT_1_RATED_DISCHARGE_POWER = "storage_unit_1_rated_discharge_power"
STORAGE_UNIT_1_FAULT_ID = "storage_unit_1_fault_id"
STORAGE_UNIT_1_CURRENT_DAY_CHARGE_CAPACITY = "storage_unit_1_current_day_charge_capacity"
STORAGE_UNIT_1_CURRENT_DAY_DISCHARGE_CAPACITY = "storage_unit_1_current_day_discharge_capacity"
STORAGE_UNIT_1_BUS_CURRENT = "storage_unit_1_bus_current"
STORAGE_UNIT_1_BATTERY_TEMPERATURE = "storage_unit_1_battery_temperature"
STORAGE_UNIT_1_REMAINING_CHARGE_DIS_CHARGE_TIME = "storage_unit_1_remaining_charge_dis_charge_time"
STORAGE_UNIT_1_DCDC_VERSION = "storage_unit_1_dcdc_version"
STORAGE_UNIT_1_BMS_VERSION = "storage_unit_1_bms_version"
STORAGE_MAXIMUM_CHARGE_POWER = "storage_maximum_charge_power"
STORAGE_MAXIMUM_DISCHARGE_POWER = "storage_maximum_discharge_power"
STORAGE_UNIT_1_SERIAL_NUMBER = "storage_unit_1_serial_number"
STORAGE_UNIT_1_TOTAL_CHARGE = "storage_unit_1_total_charge"
STORAGE_UNIT_1_TOTAL_DISCHARGE = "storage_unit_1_total_discharge"
METER_STATUS = "meter_status"
GRID_A_VOLTAGE = "grid_A_voltage"
GRID_B_VOLTAGE = "grid_B_voltage"
GRID_C_VOLTAGE = "grid_C_voltage"
ACTIVE_GRID_A_CURRENT = "active_grid_A_current"
ACTIVE_GRID_B_CURRENT = "active_grid_B_current"
ACTIVE_GRID_C_CURRENT = "active_grid_C_current"
POWER_METER_ACTIVE_POWER = "power_meter_active_power"
POWER_METER_REACTIVE_POWER = "power_meter_reactive_power"
ACTIVE_GRID_POWER_FACTOR = "active_grid_power_factor"
ACTIVE_GRID_FREQUENCY = "active_grid_frequency"
GRID_EXPORTED_ENERGY = "grid_exported_energy"
GRID_ACCUMULATED_ENERGY = "grid_accumulated_energy"
GRID_ACCUMULATED_REACTIVE_POWER = "grid_accumulated_reactive_power"
METER_TYPE = "meter_type"
ACTIVE_GRID_A_B_VOLTAGE = "active_grid_A_B_voltage"
ACTIVE_GRID_B_C_VOLTAGE = "active_grid_B_C_voltage"
ACTIVE_GRID_C_A_VOLTAGE = "active_grid_C_A_voltage"
ACTIVE_GRID_A_POWER = "active_grid_A_power"
ACTIVE_GRID_B_POWER = "active_grid_B_power"
ACTIVE_GRID_C_POWER = "active_grid_C_power"
NB_OPTIMIZERS = "nb_optimizers"
METER_TYPE_CHECK = "meter_type_check"
NB_ONLINE_OPTIMIZERS = "nb_online_optimizers"
STORAGE_UNIT_2_SERIAL_NUMBER = "storage_unit_2_serial_number"
STORAGE_UNIT_2_STATE_OF_CAPACITY = "storage_unit_2_state_of_capacity"
STORAGE_UNIT_2_RUNNING_STATUS = "storage_unit_2_running_status"
STORAGE_UNIT_2_CHARGE_DISCHARGE_POWER = "storage_unit_2_charge_discharge_power"
STORAGE_UNIT_2_CURRENT_DAY_CHARGE_CAPACITY = "storage_unit_2_current_day_charge_capacity"
STORAGE_UNIT_2_CURRENT_DAY_DISCHARGE_CAPACITY = "storage_unit_2_current_day_discharge_capacity"
STORAGE_UNIT_2_BUS_VOLTAGE = "storage_unit_2_bus_voltage"
STORAGE_UNIT_2_BUS_CURRENT = "storage_unit_2_bus_current"
STORAGE_UNIT_2_BATTERY_TEMPERATURE = "storage_unit_2_battery_temperature"
STORAGE_UNIT_2_TOTAL_CHARGE = "storage_unit_2_total_charge"
STORAGE_UNIT_2_TOTAL_DISCHARGE = "storage_unit_2_total_discharge"
STORAGE_RATED_CAPACITY = "storage_rated_capacity"
STORAGE_STATE_OF_CAPACITY = "storage_state_of_capacity"
STORAGE_RUNNING_STATUS = "storage_running_status"
STORAGE_BUS_VOLTAGE = "storage_bus_voltage"
STORAGE_BUS_CURRENT = "storage_bus_current"
STORAGE_CHARGE_DISCHARGE_POWER = "storage_charge_discharge_power"
STORAGE_TOTAL_CHARGE = "storage_total_charge"
STORAGE_TOTAL_DISCHARGE = "storage_total_discharge"
STORAGE_CURRENT_DAY_CHARGE_CAPACITY = "storage_current_day_charge_capacity"
STORAGE_CURRENT_DAY_DISCHARGE_CAPACITY = "storage_current_day_discharge_capacity"
STORAGE_UNIT_2_SOFTWARE_VERSION = "storage_unit_2_software_version"
STORAGE_UNIT_1_SOFTWARE_VERSION = "storage_unit_1_software_version"
STORAGE_UNIT_1_BATTERY_PACK_1_SERIAL_NUMBER = "storage_unit_1_battery_pack_1_serial_number"
STORAGE_UNIT_1_BATTERY_PACK_1_FIRMWARE_VERSION = "storage_unit_1_battery_pack_1_firmware_version"
STORAGE_UNIT_1_BATTERY_PACK_1_WORKING_STATUS = "storage_unit_1_battery_pack_1_working_status"
STORAGE_UNIT_1_BATTERY_PACK_1_STATE_OF_CAPACITY = "storage_unit_1_battery_pack_1_state_of_capacity"
STORAGE_UNIT_1_BATTERY_PACK_1_CHARGE_DISCHARGE_POWER = "storage_unit_1_battery_pack_1_charge_discharge_power"
STORAGE_UNIT_1_BATTERY_PACK_1_VOLTAGE = "storage_unit_1_battery_pack_1_voltage"
STORAGE_UNIT_1_BATTERY_PACK_1_CURRENT = "storage_unit_1_battery_pack_1_current"
STORAGE_UNIT_1_BATTERY_PACK_1_TOTAL_CHARGE = "storage_unit_1_battery_pack_1_total_charge"
STORAGE_UNIT_1_BATTERY_PACK_1_TOTAL_DISCHARGE = "storage_unit_1_battery_pack_1_total_discharge"
STORAGE_UNIT_1_BATTERY_PACK_2_SERIAL_NUMBER = "storage_unit_1_battery_pack_2_serial_number"
STORAGE_UNIT_1_BATTERY_PACK_2_FIRMWARE_VERSION = "storage_unit_1_battery_pack_2_firmware_version"
STORAGE_UNIT_1_BATTERY_PACK_2_WORKING_STATUS = "storage_unit_1_battery_pack_2_working_status"
STORAGE_UNIT_1_BATTERY_PACK_2_STATE_OF_CAPACITY = "storage_unit_1_battery_pack_2_state_of_capacity"
STORAGE_UNIT_1_BATTERY_PACK_2_CHARGE_DISCHARGE_POWER = "storage_unit_1_battery_pack_2_charge_discharge_power"
STORAGE_UNIT_1_BATTERY_PACK_2_VOLTAGE = "storage_unit_1_battery_pack_2_voltage"
STORAGE_UNIT_1_BATTERY_PACK_2_CURRENT = "storage_unit_1_battery_pack_2_current"
STORAGE_UNIT_1_BATTERY_PACK_2_TOTAL_CHARGE = "storage_unit_1_battery_pack_2_total_charge"
STORAGE_UNIT_1_BATTERY_PACK_2_TOTAL_DISCHARGE = "storage_unit_1_battery_pack_2_total_discharge"
STORAGE_UNIT_1_BATTERY_PACK_3_SERIAL_NUMBER = "storage_unit_1_battery_pack_3_serial_number"
STORAGE_UNIT_1_BATTERY_PACK_3_FIRMWARE_VERSION = "storage_unit_1_battery_pack_3_firmware_version"
STORAGE_UNIT_1_BATTERY_PACK_3_WORKING_STATUS = "storage_unit_1_battery_pack_3_working_status"
STORAGE_UNIT_1_BATTERY_PACK_3_STATE_OF_CAPACITY = "storage_unit_1_battery_pack_3_state_of_capacity"
STORAGE_UNIT_1_BATTERY_PACK_3_CHARGE_DISCHARGE_POWER = "storage_unit_1_battery_pack_3_charge_discharge_power"
STORAGE_UNIT_1_BATTERY_PACK_3_VOLTAGE = "storage_unit_1_battery_pack_3_voltage"
STORAGE_UNIT_1_BATTERY_PACK_3_CURRENT = "storage_unit_1_battery_pack_3_current"
STORAGE_UNIT_1_BATTERY_PACK_3_TOTAL_CHARGE = "storage_unit_1_battery_pack_3_total_charge"
STORAGE_UNIT_1_BATTERY_PACK_3_TOTAL_DISCHARGE = "storage_unit_1_battery_pack_3_total_discharge"
STORAGE_UNIT_2_BATTERY_PACK_1_SERIAL_NUMBER = "storage_unit_2_battery_pack_1_serial_number"
STORAGE_UNIT_2_BATTERY_PACK_1_FIRMWARE_VERSION = "storage_unit_2_battery_pack_1_firmware_version"
STORAGE_UNIT_2_BATTERY_PACK_1_WORKING_STATUS = "storage_unit_2_battery_pack_1_working_status"
STORAGE_UNIT_2_BATTERY_PACK_1_STATE_OF_CAPACITY = "storage_unit_2_battery_pack_1_state_of_capacity"
STORAGE_UNIT_2_BATTERY_PACK_1_CHARGE_DISCHARGE_POWER = "storage_unit_2_battery_pack_1_charge_discharge_power"
STORAGE_UNIT_2_BATTERY_PACK_1_VOLTAGE = "storage_unit_2_battery_pack_1_voltage"
STORAGE_UNIT_2_BATTERY_PACK_1_CURRENT = "storage_unit_2_battery_pack_1_current"
STORAGE_UNIT_2_BATTERY_PACK_1_TOTAL_CHARGE = "storage_unit_2_battery_pack_1_total_charge"
STORAGE_UNIT_2_BATTERY_PACK_1_TOTAL_DISCHARGE = "storage_unit_2_battery_pack_1_total_discharge"
STORAGE_UNIT_2_BATTERY_PACK_2_SERIAL_NUMBER = "storage_unit_2_battery_pack_2_serial_number"
STORAGE_UNIT_2_BATTERY_PACK_2_FIRMWARE_VERSION = "storage_unit_2_battery_pack_2_firmware_version"
STORAGE_UNIT_2_BATTERY_PACK_2_WORKING_STATUS = "storage_unit_2_battery_pack_2_working_status"
STORAGE_UNIT_2_BATTERY_PACK_2_STATE_OF_CAPACITY = "storage_unit_2_battery_pack_2_state_of_capacity"
STORAGE_UNIT_2_BATTERY_PACK_2_CHARGE_DISCHARGE_POWER = "storage_unit_2_battery_pack_2_charge_discharge_power"
STORAGE_UNIT_2_BATTERY_PACK_2_VOLTAGE = "storage_unit_2_battery_pack_2_voltage"
STORAGE_UNIT_2_BATTERY_PACK_2_CURRENT = "storage_unit_2_battery_pack_2_current"
STORAGE_UNIT_2_BATTERY_PACK_2_TOTAL_CHARGE = "storage_unit_2_battery_pack_2_total_charge"
STORAGE_UNIT_2_BATTERY_PACK_2_TOTAL_DISCHARGE = "storage_unit_2_battery_pack_2_total_discharge"
STORAGE_UNIT_2_BATTERY_PACK_3_SERIAL_NUMBER = "storage_unit_2_battery_pack_3_serial_number"
STORAGE_UNIT_2_BATTERY_PACK_3_FIRMWARE_VERSION = "storage_unit_2_battery_pack_3_firmware_version"
STORAGE_UNIT_2_BATTERY_PACK_3_WORKING_STATUS = "storage_unit_2_battery_pack_3_working_status"
STORAGE_UNIT_2_BATTERY_PACK_3_STATE_OF_CAPACITY = "storage_unit_2_battery_pack_3_state_of_capacity"
STORAGE_UNIT_2_BATTERY_PACK_3_CHARGE_DISCHARGE_POWER = "storage_unit_2_battery_pack_3_charge_discharge_power"
STORAGE_UNIT_2_BATTERY_PACK_3_VOLTAGE = "storage_unit_2_battery_pack_3_voltage"
STORAGE_UNIT_2_BATTERY_PACK_3_CURRENT = "storage_unit_2_battery_pack_3_current"
STORAGE_UNIT_2_BATTERY_PACK_3_TOTAL_CHARGE = "storage_unit_2_battery_pack_3_total_charge"
STORAGE_UNIT_2_BATTERY_PACK_3_TOTAL_DISCHARGE = "storage_unit_2_battery_pack_3_total_discharge"
STORAGE_UNIT_1_BATTERY_PACK_1_MAXIMUM_TEMPERATURE = "storage_unit_1_battery_pack_1_maximum_temperature"
STORAGE_UNIT_1_BATTERY_PACK_1_MINIMUM_TEMPERATURE = "storage_unit_1_battery_pack_1_minimum_temperature"
STORAGE_UNIT_1_BATTERY_PACK_2_MAXIMUM_TEMPERATURE = "storage_unit_1_battery_pack_2_maximum_temperature"
STORAGE_UNIT_1_BATTERY_PACK_2_MINIMUM_TEMPERATURE = "storage_unit_1_battery_pack_2_minimum_temperature"
STORAGE_UNIT_1_BATTERY_PACK_3_MAXIMUM_TEMPERATURE = "storage_unit_1_battery_pack_3_maximum_temperature"
STORAGE_UNIT_1_BATTERY_PACK_3_MINIMUM_TEMPERATURE = "storage_unit_1_battery_pack_3_minimum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_1_MAXIMUM_TEMPERATURE = "storage_unit_2_battery_pack_1_maximum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_1_MINIMUM_TEMPERATURE = "storage_unit_2_battery_pack_1_minimum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_2_MAXIMUM_TEMPERATURE = "storage_unit_2_battery_pack_2_maximum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_2_MINIMUM_TEMPERATURE = "storage_unit_2_battery_pack_2_minimum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_3_MAXIMUM_TEMPERATURE = "storage_unit_2_battery_pack_3_maximum_temperature"
STORAGE_UNIT_2_BATTERY_PACK_3_MINIMUM_TEMPERATURE = "storage_unit_2_battery_pack_3_minimum_temperature"
SYSTEM_TIME = "system_time"
SYSTEM_TIME_RAW = "system_time_raw"
UNKNOWN_TIME_5 = "unknown_time_5"
STARTUP = "startup"
SHUTDOWN = "shutdown"
GRID_CODE = "grid_code"
TIME_ZONE = "time_zone"
STORAGE_UNIT_1_PRODUCT_MODEL = "storage_unit_1_product_model"
STORAGE_WORKING_MODE_A = "storage_working_mode_a"
STORAGE_TIME_OF_USE_PRICE = "storage_time_of_use_price"
STORAGE_TIME_OF_USE_PRICE_PERIODS = "storage_time_of_use_price_periods"
STORAGE_LCOE = "storage_lcoe"
STORAGE_MAXIMUM_CHARGING_POWER = "storage_maximum_charging_power"
STORAGE_MAXIMUM_DISCHARGING_POWER = "storage_maximum_discharging_power"
STORAGE_POWER_LIMIT_GRID_TIED_POINT = "storage_power_limit_grid_tied_point"
STORAGE_CHARGING_CUTOFF_CAPACITY = "storage_charging_cutoff_capacity"
STORAGE_DISCHARGING_CUTOFF_CAPACITY = "storage_discharging_cutoff_capacity"
STORAGE_FORCED_CHARGING_AND_DISCHARGING_PERIOD = "storage_forced_charging_and_discharging_period"
STORAGE_FORCED_CHARGING_AND_DISCHARGING_POWER = "storage_forced_charging_and_discharging_power"
STORAGE_WORKING_MODE_SETTINGS = "storage_working_mode_settings"
STORAGE_CHARGE_FROM_GRID_FUNCTION = "storage_charge_from_grid_function"
STORAGE_GRID_CHARGE_CUTOFF_STATE_OF_CHARGE = "storage_grid_charge_cutoff_state_of_charge"
STORAGE_UNIT_2_PRODUCT_MODEL = "storage_unit_2_product_model"
STORAGE_FORCIBLE_CHARGE_DISCHARGE_WRITE = "forcible_charge_discharge_write"
STORAGE_FORCIBLE_CHARGE_DISCHARGE_SOC = "storage_forcible_charge_discharge_soc"
STORAGE_BACKUP_POWER_STATE_OF_CHARGE = "storage_backup_power_state_of_charge"
STORAGE_UNIT_1_NO = "storage_unit_1_no"
STORAGE_UNIT_2_NO = "storage_unit_2_no"
STORAGE_FIXED_CHARGING_AND_DISCHARGING_PERIODS = "storage_fixed_charging_and_discharging_periods"
STORAGE_POWER_OF_CHARGE_FROM_GRID = "storage_power_of_charge_from_grid"
STORAGE_MAXIMUM_POWER_OF_CHARGE_FROM_GRID = "storage_maximum_power_of_charge_from_grid"
STORAGE_FORCIBLE_CHARGE_DISCHARGE_SETTING_MODE = "storage_forcible_charge_discharge_setting_mode"
STORAGE_FORCIBLE_CHARGE_POWER = "storage_forcible_charge_power"
STORAGE_FORCIBLE_DISCHARGE_POWER = "storage_forcible_discharge_power"
STORAGE_TIME_OF_USE_CHARGING_AND_DISCHARGING_PERIODS = "storage_time_of_use_charging_and_discharging_periods"
STORAGE_EXCESS_PV_ENERGY_USE_IN_TOU = "storage_excess_pv_energy_use_in_tou"
ACTIVE_POWER_CONTROL_MODE = "active_power_control_mode"
MAXIMUM_FEED_GRID_POWER_WATT = "maximum_feed_grid_power_watt"
MAXIMUM_FEED_GRID_POWER_PERCENT = "maximum_feed_grid_power_percent"
DONGLE_PLANT_MAXIMUM_CHARGE_FROM_GRID_POWER = "dongle_plant_maximum_charge_from_grid_power"
BACKUP_SWITCH_TO_OFF_GRID = "backup_switch_to_off_grid"
BACKUP_VOLTAGE_INDEPENDEND_OPERATION = "backup_voltage_independend_operation"
STORAGE_UNIT_1_PACK_1_NO = "storage_unit_1_pack_1_no"
STORAGE_UNIT_1_PACK_2_NO = "storage_unit_1_pack_2_no"
STORAGE_UNIT_1_PACK_3_NO = "storage_unit_1_pack_3_no"
STORAGE_UNIT_2_PACK_1_NO = "storage_unit_2_pack_1_no"
STORAGE_UNIT_2_PACK_2_NO = "storage_unit_2_pack_2_no"
STORAGE_UNIT_2_PACK_3_NO = "storage_unit_2_pack_3_no"

STORAGE_CAPACITY_CONTROL_MODE = "storage_capacity_control_mode"
STORAGE_CAPACITY_CONTROL_SOC_PEAK_SHAVING = "storage_capacity_control_soc_peak_shaving"
STORAGE_CAPACITY_CONTROL_PERIODS = "storage_capacity_control_periods"
